﻿#!/usr/bin/python
# -*- coding: utf-8 -*-

# Extractor factory, permet de créer un extractor en fonction de l'opérateur. 
def CreateExtractor(op):

   if op=="Bouygues Telecom":
      import QonsoExtractorBouygues
      return QonsoExtractorBouygues.QonsoExtractorBouygues()

   if op=="SFR":
      import QonsoExtractorSFR
      return QonsoExtractorSFR.QonsoExtractorSFR()

   if op=="Universal Mobile": 
      import QonsoExtractorUniversalMobile
      return QonsoExtractorUniversalMobile.QonsoExtractorUniversalMobile()
      
   raise RuntimeError(u'Opérateur "%s" non supporté' % op)
         